# Generated by roxygen2: do not edit by hand

S3method(print,myIO_duckdb_wasm_status)
export(addIoLayer)
export(addKeyframe)
export(clear_duckdb_wasm_cache)
export(defineCategoricalAxis)
export(dragPoints)
export(duckdb_wasm_status)
export(flipAxis)
export(install_duckdb_wasm)
export(linkCharts)
export(myIO)
export(myIOOutput)
export(myIOProxy)
export(myIO_last_error)
export(myio_chart_schema)
export(myio_function_signature)
export(myio_list_chart_types)
export(myio_list_functions)
export(myio_validate_call)
export(myio_validate_spec)
export(renderMyIO)
export(setAnnotation)
export(setAxisFormat)
export(setAxisLimits)
export(setBigData)
export(setBrush)
export(setColorScheme)
export(setExportOptions)
export(setFacet)
export(setKeyframe)
export(setLayerOpacity)
export(setLinked)
export(setLinkedCursor)
export(setMargin)
export(setReferenceLines)
export(setSlider)
export(setTheme)
export(setTitle)
export(setToggle)
export(setToolTipOptions)
export(setTransition)
export(setTransitionSpeed)
export(stepKeyframe)
export(stop_duckdb_wasm_missing)
export(suppressAxis)
export(suppressLegend)
export(updateMyIOData)
importFrom(htmlwidgets,createWidget)
importFrom(htmlwidgets,shinyRenderWidget)
importFrom(htmlwidgets,shinyWidgetOutput)
importFrom(utils,modifyList)
